@@ -3,6 +3,8 @@ Supply version information of all components
 """
 import sys
 
+from platform import python_version
+
 from .. import __version__
 from ..helpers.binaries import binarypath, run_piped_commands
 from ..helpers.download import binary_exists, ensure_binary
@@ -10,25 +12,30 @@ from ..helpers.download import binary_exists, ensure_binary
 
 def version(update=False):
     """Show version of all shipped components"""
-    print(f"kustomize-wrapper {__version__}")
+    print(f"kustomize-wrapper {__version__} (Python {python_version()})")
 
     if update:
         download_binaries()
 
+    kustomize_binary = binarypath('kustomize')
+    kubeval_binary = binarypath('kubeval')
+
     if not binary_exists('kustomize'):
-        print(f"Go binary {binarypath('kustomize')} not available.")
+        print(f"Go binary {kustomize_binary} not available.")
     if not binary_exists('kubeval'):
-        print(f"Go binary {binarypath('kubeval')} not available.")
+        print(f"Go binary {kubeval_binary} not available.")
 
     kustomize_result = run_piped_commands(
-        [f"{binarypath('kustomize')} version"])
+        [f"{kustomize_binary} version"])
     kubeval_result = run_piped_commands(
-        [f"{binarypath('kubeval')} --version"])
+        [f"{kubeval_binary} --version"])
 
     if kustomize_result.stdout:
-        print(f"Kustomize {kustomize_result.stdout.strip()}")
+        ver = kustomize_result.stdout.split()[0].split('/v')[1]
+        print(f"Kustomize {ver} ({kustomize_binary})")
     if kubeval_result.stdout:
-        print(f"Kubeval {kubeval_result.stdout.strip()}")
+        ver = kubeval_result.stdout.split()[1]
+        print(f"Kubeval {ver} ({kubeval_binary})")
 
 
 def download_binaries():
